@@ -1,11 +1,14 @@
 from app import app
 from flask import render_template
+from instagram_web.blueprints.users.views import users_blueprint
 from flask_assets import Environment, Bundle
 from .util.assets import bundles
 
 assets = Environment(app)
 assets.register(bundles)
 
+app.register_blueprint(users_blueprint, url_prefix="/users")
+
 @app.errorhandler(500)
 def internal_server_error(e):
     return render_template('500.html'), 500
